package com.fs.store.service;

import java.util.List;
import com.fs.store.domain.FsArticle;
import com.fs.store.param.FsArticleQueryParam;
import com.fs.store.vo.FsArticleListQueryVO;
import com.fs.store.vo.FsArticleVO;

/**
 * 文章Service接口
 * 
 * @author fs
 * @date 2022-03-25
 */
public interface IFsArticleService 
{
    /**
     * 查询文章
     * 
     * @param articleId 文章ID
     * @return 文章
     */
    public FsArticle selectFsArticleById(Integer articleId);

    /**
     * 查询文章列表
     * 
     * @param fsArticle 文章
     * @return 文章集合
     */
    public List<FsArticle> selectFsArticleList(FsArticle fsArticle);

    /**
     * 新增文章
     * 
     * @param fsArticle 文章
     * @return 结果
     */
    public int insertFsArticle(FsArticle fsArticle);

    /**
     * 修改文章
     * 
     * @param fsArticle 文章
     * @return 结果
     */
    public int updateFsArticle(FsArticle fsArticle);

    /**
     * 批量删除文章
     * 
     * @param articleIds 需要删除的文章ID
     * @return 结果
     */
    public int deleteFsArticleByIds(Integer[] articleIds);

    /**
     * 删除文章信息
     * 
     * @param articleId 文章ID
     * @return 结果
     */
    public int deleteFsArticleById(Integer articleId);

    List<FsArticleVO> selectFsArticleListVO(FsArticle fsArticle);

    List<FsArticleListQueryVO> selectFsArticleListQuery(FsArticleQueryParam param);


}
